@@ -5,15 +5,16 @@ test_that("PipeOpCrankCompositor - basic properties", {
   expect_equal(PipeOpCrankCompositor$new()$param_set$values$method, "mean")
 })
 
+task = tgen("simsurv")$generate(20)
+
 test_that("PipeOpCrankCompositor - assertions", {
-  expect_error(crankcompositor(lrn("surv.glmnet")), "Assertion on 'distr'")
+  expect_error(crankcompositor(lrn("surv.svm")), "Assertion on 'distr'")
   expect_error(po("crankcompose")$predict(
-    list(lrn("surv.glmnet")$train(tsk("rats"))$predict(tsk("rats")))), "Assertion on 'distr'")
+    list(lrn("surv.svm")$train(task)$predict(task))), "Assertion on 'distr'")
 })
 
 test_that("PipeOpCrankCompositor - estimate", {
   gr = crankcompositor(lrn("surv.coxph"), method = "median")
-  task = tsk("rats")
   expect_silent(gr$train(task))
   p = gr$predict(task)
   expect_prediction_surv(p)
@@ -23,7 +24,7 @@ test_that("PipeOpCrankCompositor - estimate", {
 test_that("no params",{
   po = PipeOpCrankCompositor$new(param_vals = list())
   p = po$predict(
-    list(lrn("surv.kaplan")$train(tsk("rats"))$predict(tsk("rats"))))$output
+    list(lrn("surv.kaplan")$train(task)$predict(task)))$output
   expect_prediction_surv(p)
   expect_equal(p$lp, numeric(0))
 })
